==> ttk-app-core-1.0.3.tgz: package/component/components/attachment/index.js <==
import React, { Component } from 'react'
import ReactDOM from 'react-dom'
import Popover from '../popover'
import Icon from '../icon'
import Layout from '../layout'
import DataGrid from '../datagrid'
import Upload from '../upload'
import NoData from '../nodata'
import Spin from '../spin'
import Viewer from 'react-viewer'
import classNames from 'classnames'
const Column = DataGrid.Column
const Cell = DataGrid.Cell

export default class attachmentComponent extends Component {
    constructor(props) {
        super(props)
        this.state = {
            isOpen: false,
            activeIndex: 0,
            contentIsVisible: props.visible,
            fileList: []
        }
    }

    contentVisibleChange = (visible) => {
        if (this.state.isOpen)
            return

        this.setState({ contentIsVisible: visible })
    }
    ComponentWillUpdate = () => {

    }
    download = (index) => () => {
        this.props.onDownload && this.props.onDownload(this.props.data[index])
    }

    del = (index) => () => {
        // this.setState({ contentIsVisible: true })
        this.props.onDel && this.props.onDel(this.props.data[index])
    }

    getContent = () => {
        const className = classNames({
            'mk-attachment-content': true,
            [this.props.contentClassName]: !!this.props.contentClassName
        })
        const data = this.props.data || []

        const status = this.props.status
        if (data && data.length == 0 && this.props.status != 1) {
            return (
                <div className={className + ' upload-content'}>
                    <Spin spinning={this.props.loading != undefined ? this.props.loading : false} tip='加载中...'>
                        <NoData type='noDocoments' small>
                            <span>亲，还没有文件，赶快上传呦！</span>


                        </NoData>
                    </Spin>
                </div>
            )
        }
        const columns = [
            <Column
                columnKey='link'
                flexGrow={1}
                cell={(ps) => {
                    return (
                        <Popover
                            content={this.getThumbnail(data[ps.rowIndex])}
                            arrowPointAtCenter={true}
                            placement='leftTop'
                        >
                            <Cell className='mk-attachment-content-link-cell'>
                                <a>
                                    {data[ps.rowIndex].type == 1000010001 ? <Icon type="picture" className="picture" /> : <Icon type="file" className="picture" />}
                                </a>
                                {data[ps.rowIndex].type == 1000010001 ? <a onClick={(e) => this.openViewer(ps.rowIndex, e)} title={data[ps.rowIndex].name || data[ps.rowIndex].alt}>{data[ps.rowIndex].name || data[ps.rowIndex].alt}</a> : <span title={data[ps.rowIndex].name || data[ps.rowIndex].alt}>{data[ps.rowIndex].name || data[ps.rowIndex].alt}</span>}
                            </Cell>
                        </Popover>
                    )
                }}
                width={100}
            />,
            <Column
                columnKey='option'
                cell={(ps) => (
                    <Cell>
                        <a href={ps.accessUrl} download={ps.name} onClick={this.download(ps.rowIndex)} type='download'><Icon className='download' fontFamily='edficon' title='下载' type='xiazai' /></a>
                        {this.props.status != 1 ? <a><Icon onClick={this.del(ps.rowIndex)} fontFamily='edficon' type='shanchu' title='删除' className="del" /></a> : null}
                    </Cell>
                )}
                width={70}
            />
        ]

        let loading = {
            spinning: this.props.loading != undefined ? this.props.loading : false,
            tip: '加载中...',
            size: 'default'
        }
        return (
            <div className={className}>
                <DataGrid
                    rowsCount={data ? data.length : 0}
                    rowHeight={36}
                    columns={columns}
                    isFix
                    height={210}
                    loading={loading}
                    width={250}
                />
                {/*<Layout className='mk-attachment-content-footer'>
                    <Upload
                        showUploadList={false}
                        {...this.props.uploadProps}
                    >
                        <a href="#">
                            上传<Icon type='upload' />
                        </a>
                    </Upload>
                </Layout>*/}
            </div>
        )
    }

    getTitle = () => {
        return (
            <div className="attachment-title">
                <span>附件列表</span>
                {
                    this.props.status != 1 ?
                        <Upload
                            showUploadList={false}
                            {...this.props.uploadProps}
                        >
                            <span className="upload">
                                <Icon className="upload-icon" fontFamily="edficon" type="xinzengkemu" style={{ fontSize: '25px', verticalAlign: 'bottom' }} />添加
						 </span>
                        </Upload> : null
                }
            </div>
        )
    }

    getThumbnail = (detail) => {
        if (detail.type != 1000010001) return (<div></div>)
        return (<div style={{ width: 300, height: 300 }}>
            <img height={300} width={300} src={detail.accessUrl} />
        </div>)
    }

    render() {
        const className = classNames({
            'mk-attachment': true,
            [this.props.className]: !!this.props.className
        })

        return (
            <Popover
                overlayClassName='mk-attachment-popover attachment'
                content={this.getContent()}
                placement="bottomRight"
                onVisibleChange={this.contentVisibleChange}
                visible={this.state.contentIsVisible || this.props.visible}
                title={this.getTitle()}
                trigger='click'
            >
                <span {...this.props} className={className}>
                    <Icon style={{ fontSize: '22px', verticalAlign: 'middle' }} fontFamily="edficon" type="fujian" />
                    <span style={{ display: 'inline-block', height: '24px', lineHeight: '24px', verticalAlign: 'middle' }}>附件</span>
                </span>
                {this.renderViewer(this.props.data)}
            </Popover>
        )
    }

    openViewer = (index, event) => {
        this.setState({
            isOpen: true,
            activeIndex: index
        })
    }

    closeViewer = () => {
        this.setState({
            isOpen: false,
        })
    }

    renderViewer(data) {
        if (!data) return null
        if (data.length == 0) return null
        let newData = []
        if (data instanceof Array) {
            data.forEach(item => {
                if(item.type == 1000010001){
                    newData.push({ src: item.accessUrl, alt: item.alt })
                }
            })
        }
        return (
            <Viewer
                images={newData}
                visible={this.state.isOpen}
                activeIndex={this.state.activeIndex}
                container={null}
                onClose={this.closeViewer}
            />
        )
    }
}

==> ttk-app-core-1.0.7.tgz: package/component/components/attachment/index.js <==
import React, { Component } from 'react'
import ReactDOM from 'react-dom'
import Popover from '../popover'
import Icon from '../icon'
import Layout from '../layout'
import DataGrid from '../datagrid'
import Upload from '../upload'
import NoData from '../nodata'
import Spin from '../spin'
import Viewer from 'react-viewer'
import classNames from 'classnames'
const Column = DataGrid.Column
const Cell = DataGrid.Cell

export default class attachmentComponent extends Component {
    constructor(props) {
        super(props)
        this.state = {
            isOpen: false,
            activeIndex: 0,
            contentIsVisible: props.visible,
            fileList: []
        }
    }

    contentVisibleChange = (visible) => {
        if (this.state.isOpen)
            return

        this.setState({ contentIsVisible: visible })
    }
    ComponentWillUpdate = () => {

    }
    download = (index) => () => {
        this.props.onDownload && this.props.onDownload(this.props.data[index])
    }

    del = (index) => () => {
        // this.setState({ contentIsVisible: true })
        this.props.onDel && this.props.onDel(this.props.data[index])
    }

    getContent = () => {
        const className = classNames({
            'mk-attachment-content': true,
            [this.props.contentClassName]: !!this.props.contentClassName
        })
        const data = this.props.data || []

        const status = this.props.status
        if (data && data.length == 0 && this.props.status != 1) {
            return (
                <div className={className + ' upload-content'}>
                    <Spin spinning={this.props.loading != undefined ? this.props.loading : false} tip='加载中...'>
                        <NoData type='noDocoments' small>
                            <span>亲，还没有文件，赶快上传呦！</span>


                        </NoData>
                    </Spin>
                </div>
            )
        }
        const columns = [
            <Column
                columnKey='link'
                flexGrow={1}
                cell={(ps) => {
                    return (
                        <Popover
                            content={this.getThumbnail(data[ps.rowIndex])}
                            arrowPointAtCenter={true}
                            placement='leftTop'
                        >
                            <Cell className='mk-attachment-content-link-cell'>
                                <a>
                                    {data[ps.rowIndex].type == 1000010001 ? <Icon type="picture" className="picture" /> : <Icon type="file" className="picture" />}
                                </a>
                                {data[ps.rowIndex].type == 1000010001 ? <a onClick={(e) => this.openViewer(ps.rowIndex, e)} title={data[ps.rowIndex].name || data[ps.rowIndex].alt}>{data[ps.rowIndex].name || data[ps.rowIndex].alt}</a> : <span title={data[ps.rowIndex].name || data[ps.rowIndex].alt}>{data[ps.rowIndex].name || data[ps.rowIndex].alt}</span>}
                            </Cell>
                        </Popover>
                    )
                }}
                width={100}
            />,
            <Column
                columnKey='option'
                cell={(ps) => (
                    <Cell>
                        <a href={ps.accessUrl} download={ps.name} onClick={this.download(ps.rowIndex)} type='download'><Icon className='download' fontFamily='edficon' title='下载' type='xiazai' /></a>
                        {this.props.status != 1 ? <a><Icon onClick={this.del(ps.rowIndex)} fontFamily='edficon' type='shanchu' title='删除' className="del" /></a> : null}
                    </Cell>
                )}
                width={70}
            />
        ]

        let loading = {
            spinning: this.props.loading != undefined ? this.props.loading : false,
            tip: '加载中...',
            size: 'default'
        }
        return (
            <div className={className}>
                <DataGrid
                    rowsCount={data ? data.length : 0}
                    rowHeight={36}
                    columns={columns}
                    isFix
                    height={210}
                    loading={loading}
                    width={250}
                />
                {/*<Layout className='mk-attachment-content-footer'>
                    <Upload
                        showUploadList={false}
                        {...this.props.uploadProps}
                    >
                        <a href="#">
                            上传<Icon type='upload' />
                        </a>
                    </Upload>
                </Layout>*/}
            </div>
        )
    }

    getTitle = () => {
        return (
            <div className="attachment-title">
                <span>附件列表</span>
                {
                    this.props.status != 1 ?
                        <Upload
                            showUploadList={false}
                            {...this.props.uploadProps}
                        >
                            <span className="upload">
                                <Icon className="upload-icon" fontFamily="edficon" type="xinzengkemu" style={{ fontSize: '25px', verticalAlign: 'bottom' }} />添加
						 </span>
                        </Upload> : null
                }
            </div>
        )
    }

    getThumbnail = (detail) => {
        if (detail.type != 1000010001) return (<div></div>)
        return (<div style={{ width: 300, height: 300 }}>
            <img height={300} width={300} src={detail.accessUrl} />
        </div>)
    }

    render() {
        const className = classNames({
            'mk-attachment': true,
            [this.props.className]: !!this.props.className
        })

        return (
            <Popover
                overlayClassName='mk-attachment-popover attachment'
                content={this.getContent()}
                // placement="bottomRight"
                onVisibleChange={this.contentVisibleChange}
                visible={this.state.contentIsVisible || this.props.visible}
                title={this.getTitle()}
                trigger='click'
            >
                <span {...this.props} className={className}>
                    <Icon style={{ fontSize: '22px', verticalAlign: 'middle' }} fontFamily="edficon" type="fujian" />
                    <span style={{ display: 'inline-block', height: '24px', lineHeight: '24px', verticalAlign: 'middle' }}>附件</span>
                </span>
                {this.renderViewer(this.props.data)}
            </Popover>
        )
    }

    openViewer = (index, event) => {
        this.setState({
            isOpen: true,
            activeIndex: index
        })
    }

    closeViewer = () => {
        this.setState({
            isOpen: false,
        })
    }

    renderViewer(data) {
        if (!data) return null
        if (data.length == 0) return null
        let newData = []
        if (data instanceof Array) {
            data.forEach(item => {
                if(item.type == 1000010001){
                    newData.push({ src: item.accessUrl, alt: item.alt })
                }
            })
        }
        return (
            <Viewer
                images={newData}
                visible={this.state.isOpen}
                activeIndex={this.state.activeIndex}
                container={null}
                onClose={this.closeViewer}
            />
        )
    }
}
